==> openshift-client-5.4.1-sources.jar: io/fabric8/openshift/client/handlers/operator/ServiceCatalogControllerManagerHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.operator;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.operator.ServiceCatalogControllerManagerOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManager;
import io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ServiceCatalogControllerManagerHandler implements ResourceHandler<ServiceCatalogControllerManager, ServiceCatalogControllerManagerBuilder> {

  @Override
  public String getKind() {
    return ServiceCatalogControllerManager.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public ServiceCatalogControllerManager create(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item, boolean dryRun) {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public ServiceCatalogControllerManager replace(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item, boolean dryRun) {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public ServiceCatalogControllerManager reload(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item) {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ServiceCatalogControllerManagerBuilder edit(ServiceCatalogControllerManager item) {
    return new ServiceCatalogControllerManagerBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, ServiceCatalogControllerManager item, boolean dryRun) {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item, Watcher<ServiceCatalogControllerManager> watcher) {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item, String resourceVersion, Watcher<ServiceCatalogControllerManager> watcher) {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item, ListOptions options, Watcher<ServiceCatalogControllerManager> watcher) {
  return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ServiceCatalogControllerManager waitUntilReady(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ServiceCatalogControllerManager waitUntilCondition(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item, Predicate<ServiceCatalogControllerManager> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.6.0-sources.jar: io/fabric8/openshift/client/handlers/operator/ServiceCatalogControllerManagerHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.operator;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.openshift.client.dsl.internal.operator.ServiceCatalogControllerManagerOperationsImpl;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManager;
import io.fabric8.openshift.api.model.operator.v1.ServiceCatalogControllerManagerBuilder;

public class ServiceCatalogControllerManagerHandler implements ResourceHandler<ServiceCatalogControllerManager, ServiceCatalogControllerManagerBuilder> {

  @Override
  public String getKind() {
    return ServiceCatalogControllerManager.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public ServiceCatalogControllerManagerBuilder edit(ServiceCatalogControllerManager item) {
    return new ServiceCatalogControllerManagerBuilder(item);
  }

  @Override
  public Resource<ServiceCatalogControllerManager> resource(OkHttpClient client, Config config, String namespace, ServiceCatalogControllerManager item) {
    return new ServiceCatalogControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName());
  }

}
